==> haskell-concise-0.1.0.1-225-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-concise.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 concise
version:              0.1.0.1
visibility:           public
id:                   concise-0.1.0.1-6SGDPhg8ZoP4GmwYvUIafh
key:                  concise-0.1.0.1-6SGDPhg8ZoP4GmwYvUIafh
license:              BSD-3-Clause
copyright:            Copyright (C) 2016  Fraser Tweedale
maintainer:           frase@frase.id.au
author:               Fraser Tweedale
homepage:             https://github.com/frasertweedale/hs-concise
synopsis:             Utilities for Control.Lens.Cons
description:
    concise provides a handful of functions to extend what you can
    do with Control.Lens.Cons.

category:             Data, Lenses
abi:                  8c65031863708841fae4d768f7e78ffb
exposed:              True
exposed-modules:      Control.Lens.Cons.Extras
import-dirs:          /usr/lib/ghc-8.10.2/site-local/concise-0.1.0.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/concise-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/concise-0.1.0.1
hs-libraries:         HSconcise-0.1.0.1-6SGDPhg8ZoP4GmwYvUIafh
depends:
    base-4.14.1.0 bytestring-0.10.10.0
    lens-4.19.2-4aLgIB2SmWR845riqpTmfD text-1.2.3.2

haddock-interfaces:   /usr/share/doc/haskell-concise/html/concise.haddock
haddock-html:         /usr/share/doc/haskell-concise/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-concise-0.1.0.1-226-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-concise.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 concise
version:              0.1.0.1
visibility:           public
id:                   concise-0.1.0.1-52X2NWFdAjCEabkNgVPxXc
key:                  concise-0.1.0.1-52X2NWFdAjCEabkNgVPxXc
license:              BSD-3-Clause
copyright:            Copyright (C) 2016  Fraser Tweedale
maintainer:           frase@frase.id.au
author:               Fraser Tweedale
homepage:             https://github.com/frasertweedale/hs-concise
synopsis:             Utilities for Control.Lens.Cons
description:
    concise provides a handful of functions to extend what you can
    do with Control.Lens.Cons.

category:             Data, Lenses
abi:                  c8dc2aa29193fe60aa08b10d68a9fd91
exposed:              True
exposed-modules:      Control.Lens.Cons.Extras
import-dirs:          /usr/lib/ghc-8.10.2/site-local/concise-0.1.0.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/concise-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/concise-0.1.0.1
hs-libraries:         HSconcise-0.1.0.1-52X2NWFdAjCEabkNgVPxXc
depends:
    base-4.14.1.0 bytestring-0.10.10.0
    lens-4.19.2-7P3Py8N0vH7IWbpR2IOSYm text-1.2.3.2

haddock-interfaces:   /usr/share/doc/haskell-concise/html/concise.haddock
haddock-html:         /usr/share/doc/haskell-concise/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
